flowchart.Terminal — pyqtgraph 0.11.0rc0 documentation

# flowchart.Terminal

class `pyqtgraph.flowchart.` `Terminal`(node, name, io, optional=False, multi=False, pos=None, renamable=False, removable=False, multiable=False, bypass=None)
  `__init__`(node, name, io, optional=False, multi=False, pos=None, renamable=False, removable=False, multiable=False, bypass=None)

    Construct a new terminal.

    Arguments: |
    node | the node to which this terminal belongs
    name | string, the name of the terminal
    io | ‘in’ or ‘out’
    optional | bool, whether the node may process without connection to this terminal
    multi | bool, for inputs: whether this terminal may make multiple connections for outputs: whether this terminal creates a different value for each connection
    pos | [x, y], the position of the terminal within its node’s boundaries
    renamable | (bool) Whether the terminal can be renamed by the user
    removable | (bool) Whether the terminal can be removed by the user
    multiable | (bool) Whether the user may toggle the multi option for this terminal
    bypass | (str) Name of the terminal from which this terminal’s value is derived when the Node is in bypass mode.

  `connected`(term)

    Called whenever this terminal has been connected to another. (note–this function is called on both terminals)

  `dependentNodes`()

    Return the list of nodes which receive input from this terminal.

  `disconnected`(term)

    Called whenever this terminal has been disconnected from another. (note–this function is called on both terminals)

  `inputChanged`(term, process=True)

    Called whenever there is a change to the input value to this terminal. It may often be useful to override this function.

  `inputTerminals`()

    Return the terminal(s) that give input to this one.

  `setMultiValue`(multi)

    Set whether this is a multi-value terminal.

  `setValue`(val, process=True)

    If this is a single-value terminal, val should be a single value. If this is a multi-value terminal, val should be a dict of terminal:value pairs

  `value`(term=None)

    Return the value this terminal provides for the connected terminal

  `valueIsAcceptable`()

    Returns True->acceptable None->unknown False->Unacceptable